Cobrapy BiGG Client
===================

A python API that enables programmatic access to BiGG Models database.

## Install

To install `cobrapy_bigg_client` just type:

```
pip install cobrapy_bigg_client
```

## TODO

* Implement search
